zope.event API Reference — zope.event 4.0.3dev documentation

### Navigation

- index
- next |
- previous |
- zope.event 4.0.3dev documentation »

# `zope.event` API Reference

The package exports the following API symbols.

## Data

`zope.event.` `subscribers` = []

  Applications may register for notification of events by appending a callable to the `subscribers` list.

  Each subscriber takes a single argument, which is the event object being published.

  Exceptions raised by subscribers will be propagated.

## Functions

`zope.event.` `notify`(event)

  Notify all subscribers of `event`.

### Navigation

- index
- next |
- previous |
- zope.event 4.0.3dev documentation »